/**
 * Helper to manipulate strings
 */
export declare class StringTools {
    /**
     * Checks for a matching suffix at the end of a string (for ES5 and lower)
     * @param str Source string
     * @param suffix Suffix to search for in the source string
     * @returns Boolean indicating whether the suffix was found (true) or not (false)
     */
    static EndsWith(str: string, suffix: string): boolean;
    /**
     * Checks for a matching suffix at the beginning of a string (for ES5 and lower)
     * @param str Source string
     * @param suffix Suffix to search for in the source string
     * @returns Boolean indicating whether the suffix was found (true) or not (false)
     */
    static StartsWith(str: string, suffix: string): boolean;
    /**
     * Decodes a buffer into a string
     * @param buffer The buffer to decode
     * @returns The decoded string
     */
    static Decode(buffer: Uint8Array | Uint16Array): string;
    /**
     * Encode a buffer to a base64 string
     * @param buffer defines the buffer to encode
     * @returns the encoded string
     */
    static EncodeArrayBufferToBase64(buffer: ArrayBuffer | ArrayBufferView): string;
}
