import { FontFamily, FontFamilyFace, TextSanitationResult } from '.';
/**
 * Download a list of font families so that are available for the browser
 *
 * @param fontFamilies List of font families to download
 * @returns A promise that resolves when all fonts are downloaded
 */
export declare function loadFonts(fontFamilies: FontFamily[]): Promise<void>;
/**
 * Downlod all fonts used in a design
 *
 * @param design Design to load fonts for
 * @param downloadedFonts A list of downloaded fonts
 */
export declare function downloadFontsOfDesign(design: MPlaza.Design, downloadedFonts: FontFamily[]): Promise<void>;
/**
 * Remove invalid characters from the text.
 * Invalid characters include backspace (\x08) and null (\u0000) characters.
 *
 * @param text The text to remove invalid characters from
 * @returns The text without invalid characters
 */
export declare function removeInvalidCharactersFromText(text: string): string;
/**
 * Remove unsupported characters from the text.
 * Unsupported characters include characters that cannot be displayed or processed correctly.
 * @param face The font to check character support
 * @param text The text to remove unsupported characters from
 * @returns The text without unsupported characters
 */
export declare function sanitizeString(face: FontFamilyFace, string: string): string;
/**
 * Remove unsupported characters from the text and return a list of removed characters.
 * Unsupported characters include characters that cannot be displayed or processed correctly.
 * @param face The font to check character support
 * @param text The text to remove unsupported characters from
 * @returns The text without unsupported characters and a list of removed characters
 */
export declare function sanitizeText(face: FontFamilyFace, text: string): TextSanitationResult;
/**
 * Remove invalid characters from the text based on the font file.
 * Invalid characters include whitespace or characters that are not supported by the font.
 *
 * @param text The text to remove invalid characters from
 * @param fontFile The font file used to check character support
 * @returns The text without invalid characters
 */
export declare function removeInvalidCharacters(text: string, fontFile: any): string;
/**
 * Get the parsed file from a font
 *
 * @param face The font to get the parsed file from
 * @returns The parsed file
 */
export declare function getParsedFileFromFont(face: FontFamilyFace): import("./models").FontFamilyFaceFiles | undefined;
/**
 * Remove unsupported characters from the text.
 * Unsupported characters include characters that cannot be displayed or processed correctly.
 * @param text The text to remove unsupported characters from
 * @returns The text without unsupported characters
 */
export declare function removeUnsupportedCharacters(text: string, currentFont: FontFamilyFace): string;
/**
 * Remove textual emojis from the text.
 * Textual emojis include emojis that are made up of multiple characters.
 * @param text The text to remove textual emojis from
 * @returns The text without textual emojis
 */
export declare function removeTextualEmojisFromText(text: string): string;
/**
 * Remove emojis from the text.
 * @param text The text to remove emojis from
 * @returns The text without emojis
 */
export declare function removeEmojisFromText(text: string): string;
